ButtonOptions class

Constructors

ButtonOptions(bool latchable, ButtonState state, bool supressBorder, bool transparent, bool disabled, bool noBorder)

Properties

disabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
latchable bool
getter/setter pair
noBorder bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ButtonState
getter/setter pair
supressBorder bool
getter/setter pair
transparent bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited