OutputLinearBarGraphOptions class

Constructors

OutputLinearBarGraphOptions(bool drawBorder, bool drawTargetLine, bool drawTicks, BarGraphType barGraphType, AxisOrientation axisOrientation, GrowDirection growDirection)

Properties

axisOrientation AxisOrientation
getter/setter pair
barGraphType BarGraphType
getter/setter pair
drawBorder bool
getter/setter pair
drawTargetLine bool
getter/setter pair
drawTicks bool
getter/setter pair
growDirection GrowDirection
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited