AnimationObject class

Inheritance

Constructors

AnimationObject(int id, List<Macro> macros, int width, int height, int refreshInterval, int listIndex, bool enabled, int firstChildIndex, int lastChildIndex, int defaultChildIndex, AnimationObjectOptions options, List<ReferenceObject> animationObjects)

Properties

animationObjects List<ReferenceObject>
getter/setter pair
defaultChildIndex int
getter/setter pair
enabled bool
getter/setter pair
firstChildIndex int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
id int
getter/setter pairinherited
lastChildIndex int
getter/setter pair
listIndex int
getter/setter pair
macros List<Macro>
getter/setter pairinherited
options AnimationObjectOptions
getter/setter pair
refreshInterval int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IsobusObjectType
getter/setter pairinherited
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited