Button class
- Inheritance
Constructors
-
Button(int id, IsobusColor backgroundColor, List<
ReferenceObject> objects, List<Macro> macros, int width, int height, IsobusColor borderColor, int keyCode, ButtonOptions options)
Properties
- backgroundColor ↔ IsobusColor
-
getter/setter pairinherited
- borderColor ↔ IsobusColor
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
- id ↔ int
-
getter/setter pairinherited
- keyCode ↔ int
-
getter/setter pair
-
macros
↔ List<
Macro> -
getter/setter pairinherited
-
objects
↔ List<
ReferenceObject> -
getter/setter pairinherited
- options ↔ ButtonOptions
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ IsobusObjectType
-
getter/setter pairinherited
- width ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited