Container class

Inheritance

Constructors

Container(int id, List<Macro> macros, int width, int height, bool hidden, List<ReferenceObject> childObjects)

Properties

childObjects List<ReferenceObject>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
hidden bool
getter/setter pair
id int
getter/setter pairinherited
macros List<Macro>
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IsobusObjectType
getter/setter pairinherited
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited