ExtendedInputAttributes class
- Inheritance
-
- Object
- IsobusObject
- IsobusMacroObject
- ExtendedInputAttributes
Constructors
-
ExtendedInputAttributes(int id, ValidationType validationType, List<
CodePlane> codePlanes, List<CharacterCombination> characterCombinations, List<Macro> macros)
Properties
-
characterCombinations
↔ List<
CharacterCombination> -
getter/setter pair
-
codePlanes
↔ List<
CodePlane> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int
-
getter/setter pairinherited
-
macros
↔ List<
Macro> -
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ IsobusObjectType
-
getter/setter pairinherited
- validationType ↔ ValidationType
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited