ExternalObjectPointer class
- Inheritance
-
- Object
- IsobusObject
- ExternalObjectPointer
Constructors
- ExternalObjectPointer(int id, IsobusObject defaultObject, int? exteralReferenceName, IsobusObject? externalObject)
Properties
- defaultObject ↔ IsobusObject
-
getter/setter pair
- exteralReferenceName ↔ int?
-
getter/setter pair
- externalObject ↔ IsobusObject?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ IsobusObjectType
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited