FontAttributes class

Inheritance

Constructors

FontAttributes(int id, IsobusColor fontColor, FontSize fontSize, FontType fontType, FontStyle fontStyle, List<Macro> macros)

Properties

fontColor IsobusColor
getter/setter pair
fontSize FontSize
getter/setter pair
fontStyle FontStyle
getter/setter pair
fontType FontType
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pairinherited
macros List<Macro>
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IsobusObjectType
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited