GraphicsContext class

Inheritance

Constructors

GraphicsContext(int id, int viewPortWidth, int viewPortHeight, int viewPortX, int viewPortY, int canvasWidth, int canvasHeight, Float viewPortZoom, int graphicsCursorX, int graphicsCursorY, IsobusColor foregroundColor, IsobusColor backgroundColor, FontAttributes fontAttributes, LineAttributes lineAttributes, FillAttributes fillAttributes, ColorFormat colorFormat, GraphicsContextOptions options, IsobusColor transparencyColor)

Properties

backgroundColor IsobusColor
getter/setter pair
canvasHeight int
getter/setter pair
canvasWidth int
getter/setter pair
colorFormat ColorFormat
getter/setter pair
fillAttributes FillAttributes
getter/setter pair
fontAttributes FontAttributes
getter/setter pair
foregroundColor IsobusColor
getter/setter pair
graphicsCursorX int
getter/setter pair
graphicsCursorY int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pairinherited
lineAttributes LineAttributes
getter/setter pair
options GraphicsContextOptions
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transparencyColor IsobusColor
getter/setter pair
type IsobusObjectType
getter/setter pairinherited
viewPortHeight int
getter/setter pair
viewPortWidth int
getter/setter pair
viewPortX int
getter/setter pair
viewPortY int
getter/setter pair
viewPortZoom Float
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited