KeyGroup class

Inheritance

Constructors

KeyGroup(int id, List<Macro> macros, KeyGroupOptions options, OutputString nameValue, ObjectPointer namePointer, IsobusObject icon, List<IsobusObject> referencedObjects)

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IsobusObject
getter/setter pair
id int
getter/setter pairinherited
macros List<Macro>
getter/setter pairinherited
namePointer ObjectPointer
getter/setter pair
nameValue OutputString
getter/setter pair
options KeyGroupOptions
getter/setter pair
referencedObjects List<IsobusObject>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IsobusObjectType
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited