ObjectLabelReferenceList class
- Inheritance
-
- Object
- IsobusObject
- ObjectLabelReferenceList
Constructors
-
ObjectLabelReferenceList(int id, List<
ObjectLabel> objectLabels)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int
-
getter/setter pairinherited
-
objectLabels
↔ List<
ObjectLabel> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ IsobusObjectType
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited