OutputPolygon class

Inheritance

Constructors

OutputPolygon(int id, List<Macro> macros, LineAttributes lineAttributes, int width, int height, FillAttributes fillAttributes, PolygonType polygonType, List<Point> points)

Properties

fillAttributes FillAttributes
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pairinherited
id int
getter/setter pairinherited
lineAttributes LineAttributes
getter/setter pairinherited
macros List<Macro>
getter/setter pairinherited
points List<Point>
getter/setter pair
polygonType PolygonType
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IsobusObjectType
getter/setter pairinherited
width int
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited