OutputList class
- Inheritance
-
- Object
- IsobusObject
- IsobusMacroObject
- OutputList
Constructors
-
OutputList(int id, List<
Macro> macros, int width, int height, NumberVariable? numberVariable, int value, List<int> listObjectIds)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
- id ↔ int
-
getter/setter pairinherited
-
listObjectIds
↔ List<
int> -
getter/setter pair
-
macros
↔ List<
Macro> -
getter/setter pairinherited
- numberVariable ↔ NumberVariable?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ IsobusObjectType
-
getter/setter pairinherited
- value ↔ int
-
getter/setter pair
- width ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited