OutputMeter class

Inheritance

Constructors

OutputMeter(int id, List<Macro> macros, int width, IsobusColor needleColor, IsobusColor borderColor, IsobusColor arcTickColor, OutputMeterOptions options, int numberOfTicks, int startAngle, int endAngle, int minValue, int maxValue, NumberVariable? numberVariable, int value)

Properties

arcTickColor IsobusColor
getter/setter pair
borderColor IsobusColor
getter/setter pair
endAngle int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pairinherited
macros List<Macro>
getter/setter pairinherited
maxValue int
getter/setter pair
minValue int
getter/setter pair
needleColor IsobusColor
getter/setter pair
numberOfTicks int
getter/setter pair
numberVariable NumberVariable?
getter/setter pair
options OutputMeterOptions
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startAngle int
getter/setter pair
type IsobusObjectType
getter/setter pairinherited
value int
getter/setter pair
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited