OutputNumber class
- Inheritance
-
- Object
- IsobusObject
- IsobusMacroObject
- OutputNumber
Constructors
-
OutputNumber(int id, List<
Macro> macros, int width, int height, IsobusColor backgroundColor, FontAttributes fontAttributes, OutputNumberOptions outputNumberOptions, NumberVariable? numberVariable, int value, int offset, Float scale, int numberOfDecimals, NumberFormat numberFormat, Alignment justification)
Properties
- backgroundColor ↔ IsobusColor
-
getter/setter pair
- fontAttributes ↔ FontAttributes
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
- id ↔ int
-
getter/setter pairinherited
- justification ↔ Alignment
-
getter/setter pair
-
macros
↔ List<
Macro> -
getter/setter pairinherited
- numberFormat ↔ NumberFormat
-
getter/setter pair
- numberOfDecimals ↔ int
-
getter/setter pair
- numberVariable ↔ NumberVariable?
-
getter/setter pair
- offset ↔ int
-
getter/setter pair
- outputNumberOptions ↔ OutputNumberOptions
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale ↔ Float
-
getter/setter pair
- type ↔ IsobusObjectType
-
getter/setter pairinherited
- value ↔ int
-
getter/setter pair
- width ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited