OutputString class

Inheritance

Constructors

OutputString(int id, List<Macro> macros, int width, int height, IsobusColor backgroundColor, FontAttributes fontAttributes, OutputStringOptions outputStringOptions, StringVariable stringVariable, Alignment justification, int length, String value)

Properties

backgroundColor IsobusColor
getter/setter pair
fontAttributes FontAttributes
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
id int
getter/setter pairinherited
justification Alignment
getter/setter pair
length int
getter/setter pair
macros List<Macro>
getter/setter pairinherited
outputStringOptions OutputStringOptions
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringVariable StringVariable
getter/setter pair
type IsobusObjectType
getter/setter pairinherited
value String
getter/setter pair
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited