PictureGraphic class

Inheritance

Constructors

PictureGraphic(int id, int width, int actualWidth, int actualHeight, ColorFormat colorFormat, PictureGraphicOptions options, IsobusColor transparencyColor, Image image, List<Macro> macros)

Properties

actualHeight int
getter/setter pair
actualWidth int
getter/setter pair
colorFormat ColorFormat
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pairinherited
image Image
getter/setter pair
macros List<Macro>
getter/setter pairinherited
options PictureGraphicOptions
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transparencyColor IsobusColor
getter/setter pair
type IsobusObjectType
getter/setter pairinherited
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited