WokringSetSpecialControls class

Inheritance

Constructors

WokringSetSpecialControls(int id, ColorMap colorMap, ColorPalette colorPalette, List<LanguagePair> languagePairs)

Properties

colorMap ColorMap
getter/setter pair
colorPalette ColorPalette
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pairinherited
languagePairs List<LanguagePair>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IsobusObjectType
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited