InputNumberOptions class
Constructors
- InputNumberOptions(bool transparent, bool displayLeadingZeros, bool displayZeroAsBlank, bool truncate)
Properties
- displayLeadingZeros ↔ bool
-
getter/setter pair
- displayZeroAsBlank ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transparent ↔ bool
-
getter/setter pair
- truncate ↔ bool
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited