AlarmMask class
- Inheritance
-
- Object
- IsobusObject
- IsobusMacroObject
- IsobusParent
- AlarmMask
Constructors
-
AlarmMask(int id, IsobusColor backgroundColor, List<
ReferenceObject> childObjects, List<Macro> macros, SoftKeyMask? softkeyMask, AlarmPriority priority, AcousticSignal acousticSignal)
Properties
- acousticSignal ↔ AcousticSignal
-
getter/setter pair
- backgroundColor ↔ IsobusColor
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int
-
getter/setter pairinherited
-
macros
↔ List<
Macro> -
getter/setter pairinherited
-
objects
↔ List<
ReferenceObject> -
getter/setter pairinherited
- priority ↔ AlarmPriority
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- softkeyMask ↔ SoftKeyMask?
-
getter/setter pair
- type ↔ IsobusObjectType
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited