InputString class
- Inheritance
-
- Object
- IsobusObject
- IsobusMacroObject
- InputString
Constructors
-
InputString(int id, List<
Macro> macros, int width, int height, IsobusColor backgroundColor, FontAttributes fontAttributes, InputAttributes inputAttributes, InputStringOptions inputStringOptions, StringVariable stringVariableReference, Alignment justification, int length, String value, bool enabled)
Properties
- backgroundColor ↔ IsobusColor
-
getter/setter pair
- enabled ↔ bool
-
getter/setter pair
- fontAttributes ↔ FontAttributes
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
- id ↔ int
-
getter/setter pairinherited
- inputAttributes ↔ InputAttributes
-
getter/setter pair
- inputStringOptions ↔ InputStringOptions
-
getter/setter pair
- justification ↔ Alignment
-
getter/setter pair
- length ↔ int
-
getter/setter pair
-
macros
↔ List<
Macro> -
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringVariableReference ↔ StringVariable
-
getter/setter pair
- type ↔ IsobusObjectType
-
getter/setter pairinherited
- value ↔ String
-
getter/setter pair
- width ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited