OutputEllipse class
- Inheritance
-
- Object
- IsobusObject
- IsobusMacroObject
- IsobusShape
- OutputEllipse
Constructors
-
OutputEllipse(int id, List<
Macro> macros, LineAttributes lineAttributes, int width, int height, EllipseType ellipseType, int startAngle, int endAngle, FillAttributes fillAttributes)
Properties
- ellipseType ↔ EllipseType
-
getter/setter pair
- endAngle ↔ int
-
getter/setter pair
- fillAttributes ↔ FillAttributes
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pairinherited
- id ↔ int
-
getter/setter pairinherited
- lineAttributes ↔ LineAttributes
-
getter/setter pairinherited
-
macros
↔ List<
Macro> -
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAngle ↔ int
-
getter/setter pair
- type ↔ IsobusObjectType
-
getter/setter pairinherited
- width ↔ int
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited