OutputLinearBarGraph class
- Inheritance
-
- Object
- IsobusObject
- IsobusMacroObject
- OutputLinearBarGraph
Constructors
-
OutputLinearBarGraph(int id, List<
Macro> macros, int width, int height, IsobusColor color, IsobusColor targetLineColor, OutputLinearBarGraphOptions options, int numberOfTicks, int minValue, int maxValue, NumberVariable? numberVariable, int value, NumberVariable? targetNumberVariable, int targetValue)
Properties
- color ↔ IsobusColor
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
- id ↔ int
-
getter/setter pairinherited
-
macros
↔ List<
Macro> -
getter/setter pairinherited
- maxValue ↔ int
-
getter/setter pair
- minValue ↔ int
-
getter/setter pair
- numberOfTicks ↔ int
-
getter/setter pair
- numberVariable ↔ NumberVariable?
-
getter/setter pair
- options ↔ OutputLinearBarGraphOptions
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetLineColor ↔ IsobusColor
-
getter/setter pair
- targetNumberVariable ↔ NumberVariable?
-
getter/setter pair
- targetValue ↔ int
-
getter/setter pair
- type ↔ IsobusObjectType
-
getter/setter pairinherited
- value ↔ int
-
getter/setter pair
- width ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited