WindowMask class
- Inheritance
-
- Object
- IsobusObject
- IsobusMacroObject
- WindowMask
Constructors
-
WindowMask(int id, List<
Macro> macros, int width, int height, WindowType windowType, IsobusColor backgroundColor, WindowMaskOptions options, ObjectPointer? namePointer, OutputString? nameValue, ObjectPointer? titlePointer, OutputString? titleValue, List<IsobusObject> referencedObjects, List<ReferenceObject> childObjects)
Properties
- backgroundColor ↔ IsobusColor
-
getter/setter pair
-
childObjects
↔ List<
ReferenceObject> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
- id ↔ int
-
getter/setter pairinherited
-
macros
↔ List<
Macro> -
getter/setter pairinherited
- namePointer ↔ ObjectPointer?
-
getter/setter pair
- nameValue ↔ OutputString?
-
getter/setter pair
- options ↔ WindowMaskOptions
-
getter/setter pair
-
referencedObjects
↔ List<
IsobusObject> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titlePointer ↔ ObjectPointer?
-
getter/setter pair
- titleValue ↔ OutputString?
-
getter/setter pair
- type ↔ IsobusObjectType
-
getter/setter pairinherited
- width ↔ int
-
getter/setter pair
- windowType ↔ WindowType
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited