Command enum

Inheritance
Available extensions

Values

hideShowObject → const Command
enableDisableObject → const Command
selectInputObject → const Command
escape → const Command
controlAudioSignal → const Command
setAudioVolume → const Command
changeChildLocation → const Command
changeChildPosition → const Command
changeSize → const Command
changeBackgroungColor → const Command
changeNumericValue → const Command
changeStringValue → const Command
changeEndPoint → const Command
changeFontAttributes → const Command
changeLineAttributes → const Command
changeFillAttributes → const Command
changeActiveMask → const Command
changeSoftKeyMask → const Command
changeAttribute → const Command
changePriority → const Command
changeListItem → const Command
deleteObjectPool → const Command
lockUnlockMask → const Command
executeMacro → const Command
changeObjectLabel → const Command
changePolygonPoint → const Command
changePolygonScale → const Command
graphicsContext → const Command
getAttributeValue → const Command
selectColorMapPalette → const Command
executeExtendedMacro → const Command
selectActiveWorkingSet → const Command

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Command>
A constant List of the values in this enum, in order of their declaration.